@@ -25,14 +25,14 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #'
     #' @param cards (`ReportCard`) or a list of such objects
     #' @return `self`, invisibly.
-    #' @examples
+    #' @examplesIf require("ggplot2")
     #' library(ggplot2)
     #' library(rtables)
     #'
     #' card1 <- ReportCard$new()
     #'
     #' card1$append_text("Header 2 text", "header2")
-    #' card1$append_text("A paragraph of default text", "header2")
+    #' card1$append_text("A paragraph of default text")
     #' card1$append_plot(
     #'   ggplot(iris, aes(x = Petal.Length)) + geom_histogram()
     #' )
@@ -40,11 +40,10 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' card2 <- ReportCard$new()
     #'
     #' card2$append_text("Header 2 text", "header2")
-    #' card2$append_text("A paragraph of default text", "header2")
+    #' card2$append_text("A paragraph of default text")
     #' lyt <- analyze(split_rows_by(basic_table(), "Day"), "Ozone", afun = mean)
     #' table_res2 <- build_table(lyt, airquality)
     #' card2$append_table(table_res2)
-    #' card2$append_table(iris)
     #'
     #' reporter <- Reporter$new()
     #' reporter$append_cards(list(card1, card2))
@@ -57,14 +56,14 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @description Retrieves all `ReportCard` objects contained in the `Reporter`.
     #'
     #' @return A (`list`) of [`ReportCard`] objects.
-    #' @examples
+    #' @examplesIf require("ggplot2")
     #' library(ggplot2)
     #' library(rtables)
     #'
     #' card1 <- ReportCard$new()
     #'
     #' card1$append_text("Header 2 text", "header2")
-    #' card1$append_text("A paragraph of default text", "header2")
+    #' card1$append_text("A paragraph of default text")
     #' card1$append_plot(
     #'  ggplot(iris, aes(x = Petal.Length)) + geom_histogram()
     #' )
@@ -72,11 +71,10 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' card2 <- ReportCard$new()
     #'
     #' card2$append_text("Header 2 text", "header2")
-    #' card2$append_text("A paragraph of default text", "header2")
+    #' card2$append_text("A paragraph of default text")
     #' lyt <- analyze(split_rows_by(basic_table(), "Day"), "Ozone", afun = mean)
     #' table_res2 <- build_table(lyt, airquality)
     #' card2$append_table(table_res2)
-    #' card2$append_table(iris)
     #'
     #' reporter <- Reporter$new()
     #' reporter$append_cards(list(card1, card2))
@@ -89,14 +87,14 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @param sep An optional separator to insert between each content block.
     #' Default is a `NewpageBlock$new()`object.
     #' @return `list()` list of `TableBlock`, `TextBlock`, `PictureBlock` and `NewpageBlock`.
-    #' @examples
+    #' @examplesIf require("ggplot2")
     #' library(ggplot2)
     #' library(rtables)
     #'
     #' card1 <- ReportCard$new()
     #'
     #' card1$append_text("Header 2 text", "header2")
-    #' card1$append_text("A paragraph of default text", "header2")
+    #' card1$append_text("A paragraph of default text")
     #' card1$append_plot(
     #'  ggplot(iris, aes(x = Petal.Length)) + geom_histogram()
     #' )
@@ -104,11 +102,10 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' card2 <- ReportCard$new()
     #'
     #' card2$append_text("Header 2 text", "header2")
-    #' card2$append_text("A paragraph of default text", "header2")
+    #' card2$append_text("A paragraph of default text")
     #' lyt <- analyze(split_rows_by(basic_table(), "Day"), "Ozone", afun = mean)
     #' table_res2 <- build_table(lyt, airquality)
     #' card2$append_table(table_res2)
-    #' card2$append_table(iris)
     #'
     #' reporter <- Reporter$new()
     #' reporter$append_cards(list(card1, card2))
@@ -208,7 +205,7 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @description
     #' Reinitializes a `Reporter` instance by copying the report cards and metadata from another `Reporter`.
     #' @param reporter (`Reporter`) instance to copy from.
-    #' @return `self`, invisibly.
+    #' @return invisibly self
     #' @examples
     #' reporter <- Reporter$new()
     #' reporter$from_reporter(reporter)
@@ -223,7 +220,6 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @param output_dir (`character(1)`) a path to the directory where files will be copied.
     #' @return `named list` representing the `Reporter` instance, including version information,
     #'  metadata, and report cards.
-    #'
     #' @examples
     #' reporter <- Reporter$new()
     #' tmp_dir <- file.path(tempdir(), "testdir")
@@ -231,7 +227,7 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' reporter$to_list(tmp_dir)
     to_list = function(output_dir) {
       checkmate::assert_directory_exists(output_dir)
-      rlist <- list(version = "1", cards = list())
+      rlist <- list(name = "teal Reporter", version = "1", id = self$get_id(), cards = list())
       rlist[["metadata"]] <- self$get_metadata()
       for (card in self$get_cards()) {
         # we want to have list names being a class names to indicate the class for $from_list
@@ -246,6 +242,7 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @param rlist (`named list`) representing a `Reporter` instance.
     #' @param output_dir (`character(1)`) a path to the directory from which files will be copied.
     #' @return `self`, invisibly.
+    #' @note if Report has an id when converting to JSON then It will be compared to the currently available one.
     #' @examples
     #' reporter <- Reporter$new()
     #' tmp_dir <- file.path(tempdir(), "testdir")
@@ -253,23 +250,32 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' dir.create(tmp_dir)
     #' reporter$from_list(reporter$to_list(tmp_dir), tmp_dir)
     from_list = function(rlist, output_dir) {
+      id <- self$get_id()
       checkmate::assert_list(rlist)
       checkmate::assert_directory_exists(output_dir)
-      if (rlist$version == "1") {
+      stopifnot("Report JSON has to have name slot equal to teal Reporter" = rlist$name == "teal Reporter")
+      stopifnot("Loaded Report id has to match the current instance one" = rlist$id == id)
+      if (rlist$version %in% c("1")) {
         new_cards <- list()
         cards_names <- names(rlist$cards)
         cards_names <- gsub("[.][0-9]*$", "", cards_names)
         for (iter_c in seq_along(rlist$cards)) {
           card_class <- cards_names[iter_c]
           card <- rlist$cards[[iter_c]]
-          new_card <- eval(str2lang(sprintf("%s$new()", card_class)))
+          new_card <- eval(str2lang(card_class))$new()
           new_card$from_list(card, output_dir)
           new_cards <- c(new_cards, new_card)
         }
       } else {
-        stop("The provided version is not supported")
+        stop(
+          sprintf(
+            "The provided %s reporter version is not supported.",
+            rlist$version
+          )
+        )
       }
       self$reset()
+      self$set_id(rlist$id)
       self$append_cards(new_cards)
       self$append_metadata(rlist$metadata)
       invisible(self)
@@ -285,7 +291,8 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     to_jsondir = function(output_dir) {
       checkmate::assert_directory_exists(output_dir)
       json <- self$to_list(output_dir)
-      cat(jsonlite::toJSON(json, auto_unbox = TRUE, force = TRUE),
+      cat(
+        jsonlite::toJSON(json, auto_unbox = TRUE, force = TRUE),
         file = file.path(output_dir, "Report.json")
       )
       output_dir
@@ -293,6 +300,7 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' @description Reinitializes a `Reporter` from a `JSON ` file and files in a specified directory.
     #' @param output_dir (`character(1)`) a path to the directory with files, `JSON` and statics.
     #' @return `self`, invisibly.
+    #' @note if Report has an id when converting to JSON then It will be compared to the currently available one.
     #' @examples
     #' reporter <- Reporter$new()
     #' tmp_dir <- file.path(tempdir(), "jsondir")
@@ -302,16 +310,31 @@ Reporter <- R6::R6Class( # nolint: object_name_linter.
     #' reporter$from_jsondir(tmp_dir)
     from_jsondir = function(output_dir) {
       checkmate::assert_directory_exists(output_dir)
-      checkmate::assert_true(length(list.files(output_dir)) > 0)
       dir_files <- list.files(output_dir)
-      which_json <- grep("json$", dir_files)
-      json <- jsonlite::read_json(file.path(output_dir, dir_files[which_json]))
+      stopifnot("There has to be at least one file in the loaded directory" = length(dir_files) > 0)
+      stopifnot("Report.json file has to be in the loaded directory" = "Report.json" %in% basename(dir_files))
+      json <- jsonlite::read_json(file.path(output_dir, "Report.json"))
       self$reset()
       self$from_list(json, output_dir)
       invisible(self)
+    },
+    #' @description Set the `Reporter` id
+    #' Optionally add id to a `Reporter` which will be compared when it is rebuilt from a list.
+    #' The id is added to the downloaded file name.
+    #' @param id (`character(1)`) a Report id.
+    #' @return `self`, invisibly.
+    set_id = function(id) {
+      private$id <- id
+      invisible(self)
+    },
+    #' @description Get the `Reporter` id
+    #' @return `character(1)` the `Reporter` id.
+    get_id = function() {
+      private$id
     }
   ),
   private = list(
+    id = "",
     cards = list(),
     metadata = list(),
     reactive_add_card = NULL,
